@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 my %construct = (
@@ -76,7 +76,7 @@ Syntax::Construct - Identify which non-feature constructs are used in the code.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ L<perl5100delta/Recursive sort subs>.
 
 =head3 //
 
-L<perl5100delta/Defined or operator> or L<perlop/Logical Defined-Or>.
+L<perl5100delta/Defined-or_operator> or L<perlop/Logical Defined-Or>.
 
 =head3 ?PARNO
 
@@ -116,13 +116,16 @@ L<perlre/"(?PARNO) (?-PARNO) (?+PARNO) (?R) (?0)">.
 =head3 ?<>
 
 "Named Capture Buffers" under L<perl5100delta/Regular expressions> or
-L<perlre/"(?<NAMEE<62>pattern)">.
+L<perlre/"(?E<60>NAMEE<62>pattern)">.
 
 
 =head3 ?|
 
 Not mentioned in any Delta. See L<perlre/"(?E<124>pattern)">.
 
+=for comment
+Invalid link generated in CPAN.
+
 =head3 quant+
 
 "Possessive Quantifiers" under L<perl5100delta/Regular expressions> or
@@ -196,26 +199,44 @@ changes>.
 
 =head3 \N
 
-L<perl5120delta/\N experimental regex escape>
+L<perl5120delta/\N experimental regex escape>.
 
 =head2 5.014
 
 =head3 ?^
 
+L<perl5140delta/Regular Expressions>.
+
 =head3 /r
 
+L<perl5140delta/Regular Expressions> and L<perlre/Modifiers>.
+
 =head3 /d
 
+L<perl5140delta/Regular Expressions> and L<perlre/Modifiers>.
+
 =head3 /l
 
+L<perl5140delta/Regular Expressions> and L<perlre/Modifiers>.
+
 =head3 /u
 
+L<perl5140delta/Regular Expressions> and L<perlre/Modifiers>.
+
 =head3 /a
 
+L<perl5140delta/Regular Expressions> and L<perlre/Modifiers>.
+
 =head3 auto-deref
 
+L<perl5140delta/Array and hash container functions accept
+references>. See also L<push>, L<pop>, L<shift>, L<unshift>,
+L<splice>, L<keys>, L<values>, and L<each>.
+
 =head3 ^GLOBAL_PHASE
 
+L<perl5140delta/New-global-variable-%24%7b%5eGLOBAL_PHASE%7d>.
+
 =head2 5.016
 
 No non-feature constructs were introduced in this version of Perl.
